# Jupyter Community Call
## November 17th, 2020

**Date:** November 17th, 2020, at 9am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2020-11-17/09:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)** 

**[Youtube Link](https://youtu.be/bko-v1ZZoig)**

**Please Note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* **Zach** Shout out to Isabela for reviving the Jupyter Community Calls :tada:

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* 🦌 [IPyElk 0.2.0](https://github.com/jupyrdf/ipyelk) [![Launch Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/jupyrdf/ipyelk/42db3e3?urlpath=lab%2Ftree%2Fexamples%2F_index.ipynb)
  * > Jupyter Widgets for interactive graphs _at scale_ powered by the [Eclipse Layout Kernel (ELK)](https://github.com/kieler/elkjs), [sprotty](https://github.com/eclipse/sprotty), [networkx](https://networkx.github.io).

* [dgaf](https://github.com/deathbeds/dgaf) (deathbeds generalized automation framework)

* **Eric** [What is a Jovyan?](https://jupyter.readthedocs.io/en/latest/community/content-community.html#what-is-a-jovyan)

## Attendees

|   Name           |           Institution     | GitHub Handle                     |
|------------------|---------------------------|-----------------------------------|
| Nick Bollweg     | Jupyter, Deathbeds, GTRI  | @bollwyvl @nrbgt 
|    tony fast              |                           | @deathbeds
|Eric Charles | Datalayer, Quansight | @echarles |
| Isabela Presedo-Floyd  |Quansight            |@isabela-pf |
| Zach Sailer |  Apple  |  @Zsailer |
|A. T. Darian | Two Sigma | @afshin |
